pro nis_c_DMV, seq_in, seq_out, voltcor, volterr, header, sourcedir, verbose
    
; SUB-PROGRAM of nis_proc
;
; ABSTRACT
; correct shutter closed dark values to space-dark values using Motor voltage
; correction (MVC). Uses MET-tagged MVC table. To be used for nis_c_spacedark
; interpolated dark subtraction (Dark_modes 7,8)
;
; INPUTS
; seq_in -     sequence of averaged spectra from nis_c_div
; header -     header from input FITS file. to be modified and saved 
;            with dark data as its own FITS file.
; verbose -     Toggle description of events std output.
; voltcor -     Motor Voltge correction from table 
; volterr -     Motor Voltge noise from table 
;
; OUTPUTS
; seq_out -     array of data spectra with shutter closed darks adjusted to
;        spacedarks
;
; USES
; sxpar - creads header data for keyword
; eprop_sumdif - to propagate error from dark subtraction
;
; HISTORY
; Created  06/08/00 by N. R. Izenberg for NISCAL 4.2
; Modified 06/15/00 (NRI) change single file to table driven files
;       07/20/01 (NRI) v5.0 Compliant (mainly CNISF 5.0)
; 
; NOTES
; From NIS sequence data:    
; IDL columns 1 and 2 define MET high and low word
; CNISF 5.0 column 9 = shutter in/out (0 = in)
; CNISF 5.0 Data is 131:194 for Calibration
; CNISF 5.0 Data is 195:258 for Noise
;------------------------------------------------------------------------------
; Main

seq_out=seq_in
NAX=sxpar(header,'NAXIS2')
Fname=sxpar(header,'NEAR-003')
FMET=double(strmid(fname,3,9))    ;MET of start spectrum


; Loop through sequence, adjusting each dark sequence to space level

for m = 0, NAX-1 do begin
    if seq_in(9,M) eq 0 then begin  ; apply voltage correction
        seq_out(131:194,m)=seq_in(131:194,m)+voltcor
        seq_out(195:258,m)=eprop_sumdif(seq_in(195:258,m),volterr)
    ENDIF
endfor

if verbose eq 1 then begin
    print,'  STEP 2b: Shutter-close darks normalized to space-dark'
endif

end
