pro nis_c_phot, seq1, verbose, yaw=yaw

; SUB-PROGRAM of nis_proc
;
; ABSTRACT
; Applies Photometric model to Cal Target Measurements
;    Normal ops view cal target at 5 degrees yaw. If
;    yaw is not 5 degrees then correction is applied to 
;    this geometry.
;
; INPUTS
; seq1 -         sequence of corrected spectra from nis_c_slit in DN
; sourcedir -     source directory for NISCAL programs and data
; verbose -     Toggle description of events std output.
; yaw -         spacecraft yaw, hardcode or input from spice.
;
; OUTPUTS
; seq1 -     spectra scaled by Cal target reflectance at s/c geometry.
;
; USES
; Equation hardcoded from Relab data of cal target provided by S. Murchie
;
; HISTORY
; Created  10/01/97 by N. R. Izenberg 
; Modified 01/19/98 (NRI) V1.2 directory structure (No actual mod needed)
; Modified 07/15/98 (NRI) v2.0 compliant - CNFF format        
;       07/22/01 (NRI) v5.0 Compliant (CNISF changes mostly)
; NOTES
; From NIS sequence data:    
; IDL columns 1 and 2 define MET high and low word
; CNISF 5.0 column 9 = shutter in/out (0 = in)
; CNISF 5.0 Data is 131:194 for Calibration
; CNISF 5.0 Data is 195:258 for Noise
; Other correction equations can replace the initial relationship, but must
;     be done within this procedure.
;------------------------------------------------------------------------------
; Main

; reflectance ratio is exp(-0.15764*sqrt(degrees off specular)
; normal operations ratio is for 5 degrees yaw or 25 degrees off specular

nrmyaw = exp(-0.15764*sqrt(30-5.))
actyaw = exp(-0.15764*sqrt(30-yaw))

phot_cor = actyaw/nrmyaw


; Go through spectra and Multiply by photometric correction 
;--------------------------------------------------------------------------

sz=size(seq1)
for j = 0, sz(2)-1 do begin    
    seq1(131:194,j)=seq1(131:194,j)*phot_cor
endfor    

if verbose eq 1 then begin
    print,'    >>>> Spacecraft yaw = ',yaw
    print,'    >>>> Correction factor = ',phot_cor
    print,'  STEP 7: Photometric correction for Cal target applied'
endif

end
